==> kdnssd-5.79.1-1-armv7h.pkg.tar.xz: usr/include/KF5/KDNSSD/dnssd/kdnssd_export.h <==

#ifndef KDNSSD_EXPORT_H
#define KDNSSD_EXPORT_H

#ifdef KDNSSD_STATIC_DEFINE
#  define KDNSSD_EXPORT
#  define KDNSSD_NO_EXPORT
#else
#  ifndef KDNSSD_EXPORT
#    ifdef KF5DNSSD_EXPORTS
        /* We are building this library */
#      define KDNSSD_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KDNSSD_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KDNSSD_NO_EXPORT
#    define KDNSSD_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KDNSSD_DECL_DEPRECATED
#  define KDNSSD_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KDNSSD_DECL_DEPRECATED_EXPORT
#  define KDNSSD_DECL_DEPRECATED_EXPORT KDNSSD_EXPORT KDNSSD_DECL_DEPRECATED
#endif

#ifndef KDNSSD_DECL_DEPRECATED_NO_EXPORT
#  define KDNSSD_DECL_DEPRECATED_NO_EXPORT KDNSSD_NO_EXPORT KDNSSD_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KDNSSD_NO_DEPRECATED
#    define KDNSSD_NO_DEPRECATED
#  endif
#endif

#define KDNSSD_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KDNSSD_NO_DEPRECATED) && !defined(KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KDNSSD_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KDNSSD_NO_DEPRECATED_WARNINGS) && !defined(KDNSSD_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KDNSSD_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KDNSSD_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KDNSSD_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KDNSSD_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KDNSSD_NO_DEPRECATED)
#  undef KDNSSD_DEPRECATED
#  define KDNSSD_DEPRECATED_EXPORT KDNSSD_EXPORT
#  define KDNSSD_DEPRECATED_NO_EXPORT KDNSSD_NO_EXPORT
#elif defined(KDNSSD_NO_DEPRECATED_WARNINGS)
#  define KDNSSD_DEPRECATED
#  define KDNSSD_DEPRECATED_EXPORT KDNSSD_EXPORT
#  define KDNSSD_DEPRECATED_NO_EXPORT KDNSSD_NO_EXPORT
#else
#  define KDNSSD_DEPRECATED KDNSSD_DECL_DEPRECATED
#  define KDNSSD_DEPRECATED_EXPORT KDNSSD_DECL_DEPRECATED_EXPORT
#  define KDNSSD_DEPRECATED_NO_EXPORT KDNSSD_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KDNSSD_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KDNSSD_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KDNSSD_NO_DEPRECATED
#  define KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54f00
#endif
#ifdef KDNSSD_NO_DEPRECATED_WARNINGS
#  define KDNSSD_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KDNSSD_DEPRECATED_WARNINGS_SINCE
#  ifdef KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KDNSSD_DEPRECATED_WARNINGS_SINCE KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KDNSSD_DEPRECATED_WARNINGS_SINCE 0x54f00
#  endif
#endif

#ifndef KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KDNSSD_DEPRECATED
#  define KDNSSD_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KDNSSD_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KDNSSD_DEPRECATED_WARNINGS_SINCE >= 0x40000
#  define KDNSSD_DEPRECATED_VERSION_4_0(text) KDNSSD_DECL_DEPRECATED_TEXT(text)
#else
#  define KDNSSD_DEPRECATED_VERSION_4_0(text)
#endif
#define KDNSSD_DEPRECATED_VERSION_4(minor, text)      KDNSSD_DEPRECATED_VERSION_4_##minor(text)
#define KDNSSD_DEPRECATED_VERSION(major, minor, text) KDNSSD_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KDNSSD_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDNSSD_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)

#endif /* KDNSSD_EXPORT_H */

==> kdnssd-5.81.0-1-armv7h.pkg.tar.xz: usr/include/KF5/KDNSSD/dnssd/kdnssd_export.h <==

#ifndef KDNSSD_EXPORT_H
#define KDNSSD_EXPORT_H

#ifdef KDNSSD_STATIC_DEFINE
#  define KDNSSD_EXPORT
#  define KDNSSD_NO_EXPORT
#else
#  ifndef KDNSSD_EXPORT
#    ifdef KF5DNSSD_EXPORTS
        /* We are building this library */
#      define KDNSSD_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KDNSSD_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KDNSSD_NO_EXPORT
#    define KDNSSD_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KDNSSD_DECL_DEPRECATED
#  define KDNSSD_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KDNSSD_DECL_DEPRECATED_EXPORT
#  define KDNSSD_DECL_DEPRECATED_EXPORT KDNSSD_EXPORT KDNSSD_DECL_DEPRECATED
#endif

#ifndef KDNSSD_DECL_DEPRECATED_NO_EXPORT
#  define KDNSSD_DECL_DEPRECATED_NO_EXPORT KDNSSD_NO_EXPORT KDNSSD_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KDNSSD_NO_DEPRECATED
#    define KDNSSD_NO_DEPRECATED
#  endif
#endif

#define KDNSSD_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KDNSSD_NO_DEPRECATED) && !defined(KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KDNSSD_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KDNSSD_NO_DEPRECATED_WARNINGS) && !defined(KDNSSD_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KDNSSD_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KDNSSD_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KDNSSD_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KDNSSD_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KDNSSD_NO_DEPRECATED)
#  undef KDNSSD_DEPRECATED
#  define KDNSSD_DEPRECATED_EXPORT KDNSSD_EXPORT
#  define KDNSSD_DEPRECATED_NO_EXPORT KDNSSD_NO_EXPORT
#elif defined(KDNSSD_NO_DEPRECATED_WARNINGS)
#  define KDNSSD_DEPRECATED
#  define KDNSSD_DEPRECATED_EXPORT KDNSSD_EXPORT
#  define KDNSSD_DEPRECATED_NO_EXPORT KDNSSD_NO_EXPORT
#else
#  define KDNSSD_DEPRECATED KDNSSD_DECL_DEPRECATED
#  define KDNSSD_DEPRECATED_EXPORT KDNSSD_DECL_DEPRECATED_EXPORT
#  define KDNSSD_DEPRECATED_NO_EXPORT KDNSSD_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KDNSSD_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KDNSSD_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KDNSSD_NO_DEPRECATED
#  define KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55100
#endif
#ifdef KDNSSD_NO_DEPRECATED_WARNINGS
#  define KDNSSD_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KDNSSD_DEPRECATED_WARNINGS_SINCE
#  ifdef KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KDNSSD_DEPRECATED_WARNINGS_SINCE KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KDNSSD_DEPRECATED_WARNINGS_SINCE 0x55100
#  endif
#endif

#ifndef KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KDNSSD_DEPRECATED
#  define KDNSSD_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KDNSSD_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KDNSSD_DEPRECATED_WARNINGS_SINCE >= 0x40000
#  define KDNSSD_DEPRECATED_VERSION_4_0(text) KDNSSD_DECL_DEPRECATED_TEXT(text)
#else
#  define KDNSSD_DEPRECATED_VERSION_4_0(text)
#endif
#define KDNSSD_DEPRECATED_VERSION_4(minor, text)      KDNSSD_DEPRECATED_VERSION_4_##minor(text)
#define KDNSSD_DEPRECATED_VERSION(major, minor, text) KDNSSD_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KDNSSD_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDNSSD_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)

#endif /* KDNSSD_EXPORT_H */
